==> lsp-plugins_1.2.2.orig.tar.gz: lsp-plugins/modules/lsp-dsp-lib/src/test/utest/pcomplex/cvt.cpp <==
/*
 * Copyright (C) 2020 Linux Studio Plugins Project <https://lsp-plug.in/>
 *           (C) 2020 Vladimir Sadovnikov <sadko4u@gmail.com>
 *
 * This file is part of lsp-dsp-lib
 * Created on: 31 мар. 2020 г.
 *
 * lsp-dsp-lib is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 *
 * lsp-dsp-lib is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with lsp-dsp-lib. If not, see <https://www.gnu.org/licenses/>.
 */

#include <lsp-plug.in/dsp/dsp.h>
#include <lsp-plug.in/test-fw/utest.h>
#include <lsp-plug.in/test-fw/FloatBuffer.h>

namespace lsp
{
    namespace generic
    {
        void pcomplex_r2c(float *dst, const float *src, size_t count);
        void pcomplex_c2r(float *dst, const float *src, size_t count);
    }

    IF_ARCH_X86(
        namespace sse
        {
            void pcomplex_r2c(float *dst, const float *src, size_t count);
            void pcomplex_c2r(float *dst, const float *src, size_t count);
        }
    )

    IF_ARCH_ARM(
        namespace neon_d32
        {
            void pcomplex_r2c(float *dst, const float *src, size_t count);
            void pcomplex_c2r(float *dst, const float *src, size_t count);
        }
    )

    IF_ARCH_AARCH64(
        namespace asimd
        {
            void pcomplex_r2c(float *dst, const float *src, size_t count);
            void pcomplex_c2r(float *dst, const float *src, size_t count);
        }
    )

    typedef void (* complex_cvt_t) (float *dst, const float *src, size_t count);
}

UTEST_BEGIN("dsp.pcomplex", cvt)

    void call(const char *label, size_t align, size_t sk, size_t dk, complex_cvt_t func1, complex_cvt_t func2)
    {
        if (!UTEST_SUPPORTED(func1))
            return;
        if (!UTEST_SUPPORTED(func2))
            return;

        UTEST_FOREACH(count, 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16,
                32, 33, 37, 48, 49, 64, 65, 0x3f, 100, 999, 0x1fff)
        {
            for (size_t mask=0; mask <= 0x03; ++mask)
            {
                printf("Testing %s on input buffer of %d numbers, mask=0x%x...\n", label, int(count), int(mask));

                FloatBuffer src(count*sk, align, mask & 0x01);
                FloatBuffer dst1(count*dk, align, mask & 0x02);
                FloatBuffer dst2(dst1);

                // Call functions
                func1(dst1, src, count);
                func2(dst2, src, count);

                UTEST_ASSERT_MSG(src.valid(), "Source buffer corrupted");
                UTEST_ASSERT_MSG(dst1.valid(), "Destination buffer 1 corrupted");
                UTEST_ASSERT_MSG(dst2.valid(), "Destination buffer 2 corrupted");

                // Compare buffers
                if (!dst1.equals_absolute(dst2, 1e-5))
                {
                    src.dump("dst");
                    dst1.dump("dst1");
                    dst2.dump("dst2");
                    UTEST_FAIL_MSG("Output of functions for test '%s' differs", label);
                }
            }
        }
    }

    UTEST_MAIN
    {
        IF_ARCH_X86(call("sse::pcomplex_r2c", 16, 1, 2, generic::pcomplex_r2c, sse::pcomplex_r2c));
        IF_ARCH_X86(call("sse::pcomplex_c2r", 16, 2, 1, generic::pcomplex_c2r, sse::pcomplex_c2r));

        IF_ARCH_ARM(call("neon_d32::pcomplex_r2c", 16, 1, 2, generic::pcomplex_r2c, neon_d32::pcomplex_r2c));
        IF_ARCH_ARM(call("neon_d32::pcomplex_c2r", 16, 2, 1, generic::pcomplex_c2r, neon_d32::pcomplex_c2r));

        IF_ARCH_AARCH64(call("asimd::pcomplex_r2c", 16, 1, 2, generic::pcomplex_r2c, asimd::pcomplex_r2c));
        IF_ARCH_AARCH64(call("asimd::pcomplex_c2r", 16, 2, 1, generic::pcomplex_c2r, asimd::pcomplex_c2r));
    }

UTEST_END

==> lsp-plugins_1.2.5.orig.tar.gz: lsp-plugins/modules/lsp-dsp-lib/src/test/utest/pcomplex/cvt.cpp <==
/*
 * Copyright (C) 2020 Linux Studio Plugins Project <https://lsp-plug.in/>
 *           (C) 2020 Vladimir Sadovnikov <sadko4u@gmail.com>
 *
 * This file is part of lsp-dsp-lib
 * Created on: 31 мар. 2020 г.
 *
 * lsp-dsp-lib is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 *
 * lsp-dsp-lib is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with lsp-dsp-lib. If not, see <https://www.gnu.org/licenses/>.
 */

#include <lsp-plug.in/common/types.h>
#include <lsp-plug.in/test-fw/utest.h>
#include <lsp-plug.in/test-fw/FloatBuffer.h>

namespace lsp
{
    namespace generic
    {
        void pcomplex_r2c(float *dst, const float *src, size_t count);
        void pcomplex_c2r(float *dst, const float *src, size_t count);
    }

    IF_ARCH_X86(
        namespace sse
        {
            void pcomplex_r2c(float *dst, const float *src, size_t count);
            void pcomplex_c2r(float *dst, const float *src, size_t count);
        }
    )

    IF_ARCH_ARM(
        namespace neon_d32
        {
            void pcomplex_r2c(float *dst, const float *src, size_t count);
            void pcomplex_c2r(float *dst, const float *src, size_t count);
        }
    )

    IF_ARCH_AARCH64(
        namespace asimd
        {
            void pcomplex_r2c(float *dst, const float *src, size_t count);
            void pcomplex_c2r(float *dst, const float *src, size_t count);
        }
    )

    typedef void (* complex_cvt_t) (float *dst, const float *src, size_t count);
}

UTEST_BEGIN("dsp.pcomplex", cvt)

    void call(const char *label, size_t align, size_t sk, size_t dk, complex_cvt_t func1, complex_cvt_t func2)
    {
        if (!UTEST_SUPPORTED(func1))
            return;
        if (!UTEST_SUPPORTED(func2))
            return;

        UTEST_FOREACH(count, 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16,
                32, 33, 37, 48, 49, 64, 65, 0x3f, 100, 999, 0x1fff)
        {
            for (size_t mask=0; mask <= 0x03; ++mask)
            {
                printf("Testing %s on input buffer of %d numbers, mask=0x%x...\n", label, int(count), int(mask));

                FloatBuffer src(count*sk, align, mask & 0x01);
                FloatBuffer dst1(count*dk, align, mask & 0x02);
                FloatBuffer dst2(dst1);

                // Call functions
                func1(dst1, src, count);
                func2(dst2, src, count);

                UTEST_ASSERT_MSG(src.valid(), "Source buffer corrupted");
                UTEST_ASSERT_MSG(dst1.valid(), "Destination buffer 1 corrupted");
                UTEST_ASSERT_MSG(dst2.valid(), "Destination buffer 2 corrupted");

                // Compare buffers
                if (!dst1.equals_absolute(dst2, 1e-5))
                {
                    src.dump("dst");
                    dst1.dump("dst1");
                    dst2.dump("dst2");
                    UTEST_FAIL_MSG("Output of functions for test '%s' differs", label);
                }
            }
        }
    }

    UTEST_MAIN
    {
        IF_ARCH_X86(call("sse::pcomplex_r2c", 16, 1, 2, generic::pcomplex_r2c, sse::pcomplex_r2c));
        IF_ARCH_X86(call("sse::pcomplex_c2r", 16, 2, 1, generic::pcomplex_c2r, sse::pcomplex_c2r));

        IF_ARCH_ARM(call("neon_d32::pcomplex_r2c", 16, 1, 2, generic::pcomplex_r2c, neon_d32::pcomplex_r2c));
        IF_ARCH_ARM(call("neon_d32::pcomplex_c2r", 16, 2, 1, generic::pcomplex_c2r, neon_d32::pcomplex_c2r));

        IF_ARCH_AARCH64(call("asimd::pcomplex_r2c", 16, 1, 2, generic::pcomplex_r2c, asimd::pcomplex_r2c));
        IF_ARCH_AARCH64(call("asimd::pcomplex_c2r", 16, 2, 1, generic::pcomplex_c2r, asimd::pcomplex_c2r));
    }

UTEST_END
